==> xmms-singit_0.1.18.orig.tar.gz: xmms-singit-0.1.18.orig/src/displayer/opengl/cscene.h <==
/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __CSCENE_H__
#define __CSCENE_H__

#include "ctexture.h"
#include "ccamera.h"
#include "clyrictextengine.h"
#include "singit_song.h"

class CScene {
private:
	/* Initializators */
	bool generate_pcm_texture(void);
	void construct_ring(int elements, float ur, float dr, float h2, float *rgba_p);
	void build_world_rings(void);

	/* Actual drawers */
	void draw_world_rings(bool animate);
	void draw_bg_mesh(void);
	void draw_xmms_logo(bool animate);
	void draw_madspin(void);
	void draw_pcm(void);

	GTimeVal last_rtc_time, new_rtc_time;

protected:
	CTexture mesh_texture;
	CTexture logo_texture;
	CTexture pcm_texture;
	CTexture growbar_texture;
	CTexture madspin_star_one;
	CTexture madspin_star_two;

	CCamera camera;
	CLyricTextEngine lyric_text_engine;

	gint32 world_gl_list;

	gfloat frame;
	gfloat total;
	gfloat texsize;

public:
	CScene();
	virtual ~CScene();

	void draw(guint time, bool animate);
	void set_song(LSong *song) { lyric_text_engine.set_song(song); }
};

#endif // __CSCENE_H__

==> xmms-singit_0.1.27.orig.tar.gz: xmms-singit-0.1.27/src/displayer/opengl/cscene.h <==
/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __CSCENE_H__
#define __CSCENE_H__

#include "ctexture.h"
#include "ccamera.h"
#include "clyrictextengine.h"
#include "clevelparticleengine.h"
#include "singit_song.h"

class CScene {
private:
	/* Initializators */
	bool generate_pcm_texture(void);
	void construct_ring(int elements, float ur, float dr, float h2, float *rgba_p);
	void build_world_rings(void);

	/* Actual drawers */
	void draw_world_rings(bool animate);
	void draw_bg_mesh(void);
	void draw_xmms_logo(bool animate);
	void draw_madspin(void);
	void draw_pcm(void);

	GTimeVal last_rtc_time, new_rtc_time;

protected:
	CTexture mesh_texture;
	CTexture logo_texture;
	CTexture pcm_texture;
	CTexture growbar_texture;
	CTexture madspin_star_one;
	CTexture madspin_star_two;

	CCamera camera;
	CLyricTextEngine lyric_text_engine;
	CLevelParticleEngine level_particle_engine;

	gint32 world_gl_list;

	gfloat frame;
	gfloat total;
	gfloat texsize;

public:
	CScene();
	virtual ~CScene();

	void draw(guint time, bool animate, bool beat, gfloat level[3]);
	void set_song(SingitSong *song) { lyric_text_engine.set_song(song); }
};

#endif // __CSCENE_H__
